@@ -8,7 +8,11 @@ t_job = "job"
 t_env = "env"
 t_log = "log"
 
+t_list_output = "list_output"
+t_list_histo = "list_histo"
 t_output = "output"
+t_production = "prod"
+t_histo = "history"
 t_list = "list"
 t_send = "send"
 t_add = "installed"
